@@ -43,11 +43,19 @@ class Filesystem:
       logger.error(traceback.format_exc())
       raise Exception(f"An error occurred while trying to access {path}")
   #
+  def glob(self, path=''):
+    ls_path = FS.join(self._prefix, path) if path else self._prefix
+    return [
+      f[len(self._prefix)+1:]
+      for f in glob.glob(ls_path, recursive=True)
+      if os.path.isfile(f)
+    ]
+  #
   def ls(self, path=''):
     ls_path = FS.join(self._prefix, path) if path else self._prefix
     return [
       f[len(ls_path)+1:]
-      for f in glob.glob(ls_path + '/*') + glob.glob(ls_path + '/**/*')
+      for f in glob.glob(ls_path + '/**/*', recursive=True)
       if os.path.isfile(f)
     ]
   #
